use serde::{Deserialize, Serialize};

#[derive(Deserialize)]
#[serde(default)]
pub struct Query {
    pub page: u64,
    pub per_page: u64,
}

impl Default for Query {
    fn default() -> Self {
        Query {
            page: 1,
            per_page: 25,
        }
    }
}

#[derive(Serialize)]
pub struct PaginatedResponse<T>
where
    T: for<'de> Serialize,
{
    pub page: u64,
    pub per_page: u64,
    pub total_pages: u64,
    pub count: usize,
    pub items: Vec<T>,
}

impl Query {
    pub fn res<T: for<'de> Serialize>(
        self,
        total_pages: u64,
        items: Vec<T>,
    ) -> PaginatedResponse<T> {
        PaginatedResponse {
            page: self.page,
            per_page: self.per_page,
            total_pages,
            count: items.len(),
            items,
        }
    }
}
