pub mod entities;
mod migrator;
pub mod query;

pub use entities::{prelude::*, *};
pub use migrator::Migrator;

use sea_orm::{DeriveActiveEnum, EnumIter};
use serde::{Deserialize, Serialize};

type Result<T> = std::result::Result<T, sea_orm::DbErr>;

#[derive(EnumIter, DeriveActiveEnum, Serialize, Deserialize, PartialEq, Eq, Clone, Debug)]
#[sea_orm(rs_type = "i32", db_type = "Integer")]
#[serde(rename_all = "lowercase")]
pub enum PackageRelatedEnum {
    #[sea_orm(num_value = 0)]
    Conflicts,
    #[sea_orm(num_value = 1)]
    Replaces,
    #[sea_orm(num_value = 2)]
    Provides,
    #[sea_orm(num_value = 3)]
    Depend,
    #[sea_orm(num_value = 4)]
    Makedepend,
    #[sea_orm(num_value = 5)]
    Checkdepend,
    #[sea_orm(num_value = 6)]
    Optdepend,
}

#[derive(Serialize)]
pub struct FullPackage {
    #[serde(flatten)]
    entry: package::Model,
    licenses: Vec<String>,
    groups: Vec<String>,
    related: Vec<(PackageRelatedEnum, String)>,
    files: Vec<String>,
}
